@@ -5,9 +5,9 @@
 # See LICENSE.txt for permissions.
 #++
 
-require_relative 'command'
-require_relative 'user_interaction'
-require_relative 'text'
+require_relative "command"
+require_relative "user_interaction"
+require_relative "text"
 
 ##
 # The command manager registers and installs all the individual sub-commands
@@ -43,6 +43,7 @@ class Gem::CommandManager
     :contents,
     :dependency,
     :environment,
+    :exec,
     :fetch,
     :generate_index,
     :help,
@@ -73,9 +74,9 @@ class Gem::CommandManager
   ].freeze
 
   ALIAS_COMMANDS = {
-    'i'      => 'install',
-    'login'  => 'signin',
-    'logout' => 'signout',
+    "i" => "install",
+    "login" => "signin",
+    "logout" => "signout",
   }.freeze
 
   ##
@@ -104,7 +105,7 @@ class Gem::CommandManager
   # Register all the subcommands supported by the gem command.
 
   def initialize
-    require 'timeout'
+    require "timeout"
     @commands = {}
 
     BUILTIN_COMMANDS.each do |name|
@@ -148,7 +149,12 @@ class Gem::CommandManager
   def run(args, build_args=nil)
     process_args(args, build_args)
   rescue StandardError, Timeout::Error => ex
-    alert_error clean_text("While executing gem ... (#{ex.class})\n    #{ex}")
+    if ex.respond_to?(:detailed_message)
+      msg = ex.detailed_message(highlight: false).sub(/\A(.*?)(?: \(.+?\))/) { $1 }
+    else
+      msg = ex.message
+    end
+    alert_error clean_text("While executing gem ... (#{ex.class})\n    #{msg}")
     ui.backtrace ex
 
     terminate_interaction(1)
@@ -164,20 +170,26 @@ class Gem::CommandManager
     end
 
     case args.first
-    when '-h', '--help' then
+    when "-h", "--help" then
       say Gem::Command::HELP
       terminate_interaction 0
-    when '-v', '--version' then
+    when "-v", "--version" then
       say Gem::VERSION
       terminate_interaction 0
+    when "-C" then
+      args.shift
+      start_point = args.shift
+      if Dir.exist?(start_point)
+        Dir.chdir(start_point) { invoke_command(args, build_args) }
+      else
+        alert_error clean_text("#{start_point} isn't a directory.")
+        terminate_interaction 1
+      end
     when /^-/ then
       alert_error clean_text("Invalid option: #{args.first}. See 'gem --help'.")
       terminate_interaction 1
     else
-      cmd_name = args.shift.downcase
-      cmd = find_command cmd_name
-      cmd.deprecation_warning if cmd.deprecated?
-      cmd.invoke_with_build_args args, build_args
+      invoke_command(args, build_args)
     end
   end
 
@@ -232,4 +244,11 @@ class Gem::CommandManager
       ui.backtrace e
     end
   end
+
+  def invoke_command(args, build_args)
+    cmd_name = args.shift.downcase
+    cmd = find_command cmd_name
+    cmd.deprecation_warning if cmd.deprecated?
+    cmd.invoke_with_build_args args, build_args
+  end
 end
