@@ -5,6 +5,7 @@ require_relative "../dependency_installer"
 require_relative "../local_remote_options"
 require_relative "../validator"
 require_relative "../version_option"
+require_relative "../update_suggestion"
 
 ##
 # Gem installer command line tool
@@ -17,14 +18,15 @@ class Gem::Commands::InstallCommand < Gem::Command
   include Gem::VersionOption
   include Gem::LocalRemoteOptions
   include Gem::InstallUpdateOptions
+  include Gem::UpdateSuggestion
 
   def initialize
     defaults = Gem::DependencyInstaller::DEFAULT_OPTIONS.merge({
       :format_executable => true,
-      :lock              => true,
+      :lock => true,
       :suggest_alternate => true,
-      :version           => Gem::Requirement.default,
-      :without_groups    => [],
+      :version => Gem::Requirement.default,
+      :without_groups => [],
     })
 
     defaults.merge!(install_update_options)
@@ -168,6 +170,8 @@ You can use `i` command instead of `install`.
 
     show_installed
 
+    say update_suggestion if eglible_for_update?
+
     terminate_interaction exit_code
   end
 
