@@ -37,9 +37,6 @@ module Kernel
     return gem_original_require(path) unless Gem.discover_gems_on_require
 
     begin
-      if RUBYGEMS_ACTIVATION_MONITOR.respond_to?(:mon_owned?)
-        monitor_owned = RUBYGEMS_ACTIVATION_MONITOR.mon_owned?
-      end
       RUBYGEMS_ACTIVATION_MONITOR.enter
 
       path = path.to_path if path.respond_to? :to_path
@@ -163,13 +160,6 @@ module Kernel
       end
 
       raise load_error
-    ensure
-      if RUBYGEMS_ACTIVATION_MONITOR.respond_to?(:mon_owned?)
-        if monitor_owned != (ow = RUBYGEMS_ACTIVATION_MONITOR.mon_owned?)
-          STDERR.puts [$$, Thread.current, $!, $!.backtrace].inspect if $!
-          raise "CRITICAL: RUBYGEMS_ACTIVATION_MONITOR.owned?: before #{monitor_owned} -> after #{ow}"
-        end
-      end
     end
   end
 
