@@ -4,7 +4,6 @@
 # Kind off like BestSet but filters the sources for gems
 
 class Gem::Resolver::SourceSet < Gem::Resolver::Set
-
   ##
   # Creates a SourceSet for the given +sources+ or Gem::sources if none are
   # specified.  +sources+ must be a Gem::SourceList.
@@ -16,7 +15,7 @@ class Gem::Resolver::SourceSet < Gem::Resolver::Set
     @sets  = {}
   end
 
-  def find_all req # :nodoc:
+  def find_all(req) # :nodoc:
     if set = get_set(req.dependency.name)
       set.find_all req
     else
@@ -25,7 +24,7 @@ class Gem::Resolver::SourceSet < Gem::Resolver::Set
   end
 
   # potentially no-op
-  def prefetch reqs # :nodoc:
+  def prefetch(reqs) # :nodoc:
     reqs.each do |req|
       if set = get_set(req.dependency.name)
         set.prefetch reqs
@@ -33,16 +32,14 @@ class Gem::Resolver::SourceSet < Gem::Resolver::Set
     end
   end
 
-  def add_source_gem name, source
+  def add_source_gem(name, source)
     @links[name] = source
   end
 
-private
+  private
 
   def get_set(name)
     link = @links[name]
     @sets[link] ||= Gem::Source.new(link).dependency_resolver_set if link
   end
-
 end
-
